@@ -10,6 +10,6 @@ pub mod light;
 pub mod material;
 pub mod matrix;
 pub mod ray;
-pub mod sphere;
+pub mod shape;
 pub mod tuple;
 pub mod world;
